LogConfig class

Constructors

LogConfig({String saveDirPath = '', int maxCacheDays = 0, String fileNamePrefix = '', String publicKey = ''})
const

Properties

fileNamePrefix → String
final
hashCode → int
The hash code for this object.
no setterinherited
maxCacheDays → int
final
publicKey → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
saveDirPath → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited